@@ -1,60 +1,3 @@
-fdata2plsr2=function (fdataobj, y, ncomp = 2, norm = TRUE,method="oscorespls", ...){
-    C <- match.call()
-    if (!is.fdata(fdataobj))
-        stop("No fdata class")
-    if (is.fdata(y))  ycen<-fdata.cen(y)$Xcen
-    else  ycen = y - mean(y)
-
-    X <- fdataobj[["data"]]
-    tt <- fdataobj[["argvals"]]
-    rtt <- fdataobj[["rangeval"]]
-    nam <- fdataobj[["names"]]
-    mm <- fdata.cen(fdataobj)
-    xmean <- mm$meanX
-    Xcen.fdata <- mm$Xcen
-    n <- nrow(Xcen.fdata)
-    J <- ncol(Xcen.fdata)
-    Jmin <- min(c(ncomp, J, n))
-    cnames <- paste("PLS", seq(1, ncol(fdataobj$data)), sep = "")
-    response = "y"
-     if (is.fdata(y)) {
-       df <- data.frame(I(ycen$data), I(Xcen.fdata$data))
-       print(names(df))
-        cnames2 <- paste("PLS", seq(1, ncol(y$data)), sep = "")
-        names(df) <- c("y","X")
-        pf<-paste("y~X")
-        print(names(df))
-         }
-     else {
-     cnames <- paste("PLS", seq(1, ncol(fdataobj$data)), sep = "")
-#    ycen = y - mean(y)
-    response = "y"
-    df <- data.frame(y, Xcen.fdata$data)
-    colnames(df) <- c("y", cnames)
-    pf <- paste(response, "~", sep = "")
-    for (i in 1:length(cnames)) pf <- paste(pf, "+", cnames[i],
-        sep = "")
-         }
-    res <- plsr(as.formula(pf), ncomp = ncomp, data = df, method = method,
-        validation = "LO", ...)
-    class(res$loadings) <- "matrix"
-    vs <- fdata(t(res$loadings), tt, rtt, list(main = "pls.fdata",
-        xlab = "t", ylab = "rotationloadings"))
-    scores <- matrix(0, ncol = J, nrow = n)
-    if (norm) {
-        no <- norm.fdata(vs)
-        vs$data <- sweep(vs$data, 1, drop(no), "/")
-        scores[, 1:Jmin] <- inprod.fdata(Xcen.fdata, vs)
-    }
-    else {
-        scores[, 1:Jmin] <- inprod.fdata(Xcen.fdata, vs)
-    }
-#    colnames(scores) <- paste("PLS", 1:J, sep = "")
-    out <- list(rotation = vs, x = scores, res.pls = res, fdataobj.cen = Xcen.fdata,
-        mean = xmean, y = y, l = 1:ncomp, C = C)
-    class(out) = "fdata.comp"
-    return(out)
-}
 
 ################
 ################
@@ -94,29 +37,25 @@ if (!is.fdata(fdataobj)) fdataobj<-fdataobj(fdataobj)
     rtt<-fdataobj[["rangeval"]]
     nam<-fdataobj[["names"]]
     J <- ncol(X);n <- nrow(X)
+    center<-fdata.cen(fdataobj)
+    mean.X<-center$meanX
+    X<-center$Xcen$data
+    X0 <- X;  y0 <- y
+    mean.y <- mean(y)
+    y <- scale(y, scale = FALSE)
+if (norm)    {    
     Jmin<-min(c(J,n))
     Jmax = min(J+1,n-1)
     Beta <- matrix(, J,ncomp)
     W <- V <- Beta
     dW <- dBeta <- dV <- array(dim = c(ncomp, J, n))
-    X0 <- X;  y0 <- y
-    mean.y <- mean(y)
-    y <- scale(y, scale = FALSE)
-    center<-fdata.cen(fdataobj)
-    mean.X<-center$meanX
-    X<-center$Xcen$data
 
+ 
 #    sdx = sqrt(apply(X, 2, var))
 #    sd.X<-rep(mean(sd.X),len=J)
-#    sd.X[sd.X == 0] = 1
-if (norm)    {
- sd.X <- sqrt(apply(X, 2, var))
- X <- X/(rep(1, nrow(X)) %*% t(sd.X))
- }
-    else {
-#    X <-X/(rep(1, nrow(X)) %*%t(rep(mean(sd.X),J)))
-    sd.X<-rep(1,len=J)
-}
+#    sd.X[sd.X == 0] = 1      
+    sd.X <- sqrt(apply(X, 2, var))
+    X <- X/(rep(1, nrow(X)) %*% t(sd.X))
     repnX<-rep(1, n)
     X2<-fdata(X,tt,rtt,nam)
     dcoefficients = NULL
@@ -149,13 +88,19 @@ if (norm)    {
             DoF[i] <-traza(X %*%dBeta[i,,] + matrix(1,n, n)/n)
             }
     }
-    if (norm) {
-      V2<- fdata(t(V)*(rep(1, nrow(t(V))) %*% t(sd.X)),tt,rtt,nam)
-      V2$data<-sweep(V2$data,1,norm.fdata(V2),"/")
-      }
-    else V2<-fdata(t(V),tt,rtt,nam)
+    V2<- fdata(t(V)*(rep(1, nrow(t(V))) %*% t(sd.X)),tt,rtt,nam)
+    V2$data<-sweep(V2$data,1,norm.fdata(V2),"/")                                                
 #    V2$data<-sweep(V2$data,1,norm.fdata(V2),"/")
     DoF[DoF > Jmax] = Jmax
+    }
+    else {
+       plsr<-mplsr(X,y , K = 5,...)
+       V2<-fdata(t(plsr$loading.weights),tt,rtt,nam)
+       X2<-fdata(X,tt,rtt,nam)
+       DoF<-1:ncomp
+#    sd.X<-rep(1,len=J)
+#    V2<-fdata(t(V),tt,rtt,nam)
+   }    
     scores<-inprod.fdata(X2,V2,...)
 #    scores<-X2$data%*%V
     l<-1:ncomp
